## dbt-athena 1.9.3 - April 07, 2025

### Features

- Implement microbatch incremental strategy ([#409](https://github.com/dbt-labs/dbt-adapters/issues/409))
- Add support for sample mode ([#907](https://github.com/dbt-labs/dbt-adapters/issues/907))
